import { ItemBank, LootBank } from '../../meta/types';
import Bank from '../../structures/Bank';
import LootTable from '../../structures/LootTable';
import Minigame from '../../structures/Minigame';
export interface TeamMember {
    id: string;
    personalPoints: number;
    /**
     * Whether this team member can receive an ancient tablet, assumed false.
     *
     * Only received if players do not own one or have not consumed it already.
     */
    canReceiveAncientTablet?: boolean;
    /**
     * Whether this team member can receive Metamorphic dust.
     *
     * https://twitter.com/JagexAsh/status/1050349088124952576.
     */
    canReceiveDust?: boolean;
}
export interface ChambersOfXericOptions {
    /**
     * Whether or not this raid is in Challenge Mode or not.
     */
    challengeMode?: boolean;
    /**
     * The time in *milliseconds* that it took to complete the raid, used for rewarding with dust in challenge mode.
     */
    timeToComplete?: number;
    /**
     * The members of the raid team, can be only 1 person.
     */
    team: TeamMember[];
}
export declare const CoXUniqueTable: LootTable;
export declare class ChambersOfXericClass extends Minigame {
    id: number;
    aliases: string[];
    name: string;
    allItems: number[];
    maxRoll: number;
    /**
     * For every 8,675 total points obtained, a 1% chance to obtain a unique loot is given.
     * This chance is capped at 65.7% (570k points), further points will be sent to
     * roll for a second unique loot. A team who possesses 855,000 points in total has
     * an 65.7% chance to receive a unique loot, then a 32.85% chance to obtain a
     * second unique loot. Up to three unique rewards can be obtained per raid.
     */
    determineUniqueChancesFromTeamPoints(teamPoints: number): number[];
    /**
     * Returns true if the team is elligible to receive dust based on their
     * completion time.
     *
     * https://oldschool.runescape.wiki/w/Chambers_of_Xeric/Challenge_Mode#Rewards
     *
     * @param teamSize How many members in the raid team.
     * @param completionTime The completion time of the raid, in *milliseconds*.
     */
    elligibleForDust(teamSize: number, completionTime: number): boolean;
    rollLootFromChances(chances: number[]): Bank;
    rollNonUniqueLoot(personalPoints: number): ItemBank;
    complete(_options: ChambersOfXericOptions): LootBank;
}
export declare const ChambersOfXeric: ChambersOfXericClass;
//# sourceMappingURL=ChambersOfXeric.d.ts.map