import { ItemBank, ReturnedLootItem } from '../meta/types';
/**
 * Generate a bank based on loot table output
 * @param tableOutput
 */
export declare function bankFromLootTableOutput(tableOutput: ReturnedLootItem[]): ItemBank;
/**
 * Transforms a string-based bank to an ID-based bank
 * @param nameBank A string-based bank to convert
 */
export declare function resolveNameBank<T>(nameBank: Record<string, T>): Record<string, T>;
/**
 * Resolves a bank which uses item names or item IDs.
 * @param bank A bank to resolve
 */
export declare function resolveBank(bank: Record<string, number>): ItemBank;
/**
 * Checks if a bank includes an amount or more of an item
 * @param itemBank A NumberKeyed bank
 * @param itemID The item ID to check for
 * @param quantity The quantity of items the bank should have. Defaults to 1
 */
export declare function bankHasItem(itemBank: ItemBank, itemID: number, quantity?: number): boolean;
/**
 * Checks if a bank includes all the items from another bank
 * @param bankToHave The source bank
 * @param bankToCheck The target bank
 */
export declare function bankHasAllItemsFromBank(bankToCheck: ItemBank, bankToHave: ItemBank): boolean;
/**
 * Removes an item or a quantity of items from a bank
 * @param bank A NumberKeyed bank to remove from
 * @param itemID The item ID to remove
 * @param amountToRemove The quantity to remove. Defaults to 1
 */
export declare function removeItemFromBank(bank: ItemBank, itemID: number, amountToRemove?: number): ItemBank;
/**
 * Removes the contents of a bank from another bank
 */
export declare function removeBankFromBank(targetBank: ItemBank, bankToRemove: ItemBank): ItemBank;
/**
 * Adds an item to a bank
 * @param bank A NumberKeyed bank to add items in
 * @param itemID The item ID to add
 * @param amountToAdd Quantity of items to be added. Defaults to 1
 */
export declare function addItemToBank(bank: ItemBank, itemID: number, amountToAdd?: number): ItemBank;
/**
 * Adds an array of items in a bank
 * @param bank A NumberKeyed bank to add items to
 * @param items An array of item IDs
 */
export declare function addArrayToBank(bank: ItemBank, items: number[]): ItemBank;
/**
 * Multiplies a bank's contents by the times specified
 * @param bank A NumberKeyed bank whose contents will be multiplied
 * @param times How many times should the contents be multiplied
 */
export declare function multiplyBank(bank: ItemBank, times: number): ItemBank;
export declare function numItemsBankHasInBank(bank: ItemBank, bankItemsToHave: ItemBank): number;
export declare function fasterResolveBank(bank: ItemBank): ItemBank;
//# sourceMappingURL=bank.d.ts.map