"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.randomVariation = exports.makeRevTable = exports.revsUniqueTable = exports.getTotemChanceFromHP = exports.getAncientShardChanceFromHP = exports.convertLootBanksToItemBanks = exports.JSONClone = exports.getBrimKeyChanceFromCBLevel = exports.fromKMB = exports.toKMB = exports.convertXPtoLVL = exports.convertLVLtoXP = exports.getDate = exports.isValidUsername = exports.resolvePlayerFromHiscores = void 0;
const e_1 = require("e");
const constants_1 = require("../constants");
const LootTable_1 = __importDefault(require("../structures/LootTable"));
function resolvePlayerFromHiscores(csvData, accountType) {
    const data = csvData
        .trim()
        .split('\n')
        .map((str) => str.split(','));
    const resolvedPlayer = {
        skills: {},
        minigames: {},
        clues: {},
        bossRecords: {}
    };
    let accumulativeIndex = 0;
    for (let i = 0; i < constants_1.SKILLS.length; i++) {
        resolvedPlayer.skills[constants_1.SKILLS[i]] = {
            rank: Number(data[i][0]),
            level: Number(data[i][1]),
            xp: Number(data[i][2])
        };
    }
    if (accountType === 'seasonal') {
        resolvedPlayer.leaguePoints = {
            rank: Number(data[accumulativeIndex + constants_1.SKILLS.length][0]),
            points: Number(data[accumulativeIndex + constants_1.SKILLS.length][1])
        };
    }
    accumulativeIndex += constants_1.SKILLS.length + 1;
    for (let i = 0; i < 4; i++) {
        resolvedPlayer.minigames[constants_1.MINIGAMES[i]] = {
            rank: Number(data[i + accumulativeIndex][0]),
            score: Number(data[i + accumulativeIndex][1])
        };
    }
    accumulativeIndex += 4;
    for (let i = 0; i < constants_1.CLUES.length; i++) {
        resolvedPlayer.clues[constants_1.CLUES[i]] = {
            rank: Number(data[i + accumulativeIndex][0]),
            score: Number(data[i + accumulativeIndex][1])
        };
    }
    accumulativeIndex += constants_1.CLUES.length;
    for (let i = 0; i < 4; i++) {
        const minigameKey = constants_1.MINIGAMES[i + 4];
        const minigameData = {
            rank: Number(data[i + accumulativeIndex][0]),
            score: Number(data[i + accumulativeIndex][1])
        };
        resolvedPlayer.minigames[minigameKey] = minigameData;
    }
    accumulativeIndex += 4;
    for (let i = 0; i < constants_1.mappedBossNames.length; i++) {
        if (!data[i + accumulativeIndex])
            continue;
        const bossName = constants_1.mappedBossNames[i][0];
        resolvedPlayer.bossRecords[bossName] = {
            rank: Number(data[i + accumulativeIndex][0]),
            score: Number(data[i + accumulativeIndex][1])
        };
    }
    return resolvedPlayer;
}
exports.resolvePlayerFromHiscores = resolvePlayerFromHiscores;
/**
 * Determines whether a string is a valid RuneScape username.
 * @param username The username to check.
 */
function isValidUsername(username) {
    return Boolean(username.match('^[A-Za-z0-9]{1}[A-Za-z0-9 -_\u00A0]{0,11}$'));
}
exports.isValidUsername = isValidUsername;
/**
 * Returns the current month and year.
 */
function getDate() {
    const currentTime = new Date();
    return {
        month: currentTime.getMonth() + 1,
        year: currentTime.getFullYear()
    };
}
exports.getDate = getDate;
function convertLVLtoXP(lvl) {
    let points = 0;
    for (let i = 1; i < lvl; i++) {
        points += Math.floor(i + 300 * Math.pow(2, i / 7));
    }
    return Math.floor(points / 4);
}
exports.convertLVLtoXP = convertLVLtoXP;
function convertXPtoLVL(xp, cap = 99) {
    let points = 0;
    for (let lvl = 1; lvl <= cap; lvl++) {
        points += Math.floor(lvl + 300 * Math.pow(2, lvl / 7));
        if (Math.floor(points / 4) >= xp + 1) {
            return lvl;
        }
    }
    return cap;
}
exports.convertXPtoLVL = convertXPtoLVL;
function round(number) {
    return (Math.round(number * 100) / 100).toString();
}
function toKMB(number) {
    if (number > 999999999 || number < -999999999) {
        return `${round(number / 1000000000)}b`;
    }
    else if (number > 999999 || number < -999999) {
        return `${round(number / 1000000)}m`;
    }
    else if (number > 999 || number < -999) {
        return `${round(number / 1000)}k`;
    }
    return round(number);
}
exports.toKMB = toKMB;
function fromKMB(number) {
    number = number.toLowerCase().replace(/,/g, '');
    const [numberBefore, numberAfter] = number.split(/[.kmb]/g);
    let newNum = numberBefore;
    if (number.includes('b')) {
        newNum += numberAfter + '0'.repeat(9).slice(numberAfter.length);
    }
    else if (number.includes('m')) {
        newNum += numberAfter + '0'.repeat(6).slice(numberAfter.length);
    }
    else if (number.includes('k')) {
        newNum += numberAfter + '0'.repeat(3).slice(numberAfter.length);
    }
    return parseInt(newNum);
}
exports.fromKMB = fromKMB;
function getBrimKeyChanceFromCBLevel(combatLevel) {
    // https://twitter.com/JagexKieren/status/1083781544135847936
    if (combatLevel < 100) {
        return Math.round(0.2 * Math.pow((combatLevel - 100), 2) + 100);
    }
    return Math.max(Math.round((-1 / 5) * combatLevel + 120), 50);
}
exports.getBrimKeyChanceFromCBLevel = getBrimKeyChanceFromCBLevel;
function JSONClone(object) {
    return JSON.parse(JSON.stringify(object));
}
exports.JSONClone = JSONClone;
function convertLootBanksToItemBanks(lootResult) {
    const result = {};
    for (const [id, loot] of Object.entries(lootResult)) {
        result[id] = Object.assign({}, loot.bank);
    }
    return result;
}
exports.convertLootBanksToItemBanks = convertLootBanksToItemBanks;
function getAncientShardChanceFromHP(hitpoints) {
    return Math.round((500 - hitpoints) / 1.5);
}
exports.getAncientShardChanceFromHP = getAncientShardChanceFromHP;
function getTotemChanceFromHP(hitpoints) {
    return 500 - hitpoints;
}
exports.getTotemChanceFromHP = getTotemChanceFromHP;
exports.revsUniqueTable = new LootTable_1.default()
    .add('Amulet of avarice', 1, 2)
    .add("Craw's bow (u)", 1, 1)
    .add("Thammaron's sceptre (u)", 1, 1)
    .add("Viggora's chainmace (u)", 1, 1);
function makeRevTable(table) {
    return (options, currentLoot) => {
        const index = options.skulled ? 1 : 0;
        if ((0, e_1.roll)(table.uniqueTable[index])) {
            currentLoot.add(exports.revsUniqueTable.roll());
            return;
        }
        if ((0, e_1.roll)(table.seeds[index])) {
            currentLoot.add('Yew seed', (0, e_1.randInt)(2, 7));
            return;
        }
        if ((0, e_1.roll)(table.seeds[index])) {
            currentLoot.add('Magic seed', (0, e_1.randInt)(2, 7));
            return;
        }
        for (const [key, itemName] of [
            ['ancientEmblem', 'Ancient emblem'],
            ['ancientTotem', 'Ancient totem'],
            ['ancientCrystal', 'Ancient crystal'],
            ['ancientStatuette', 'Ancient statuette'],
            ['topThree', 'Ancient medallion'],
            ['topThree', 'Ancient effigy'],
            ['topThree', 'Ancient relic']
        ]) {
            if ((0, e_1.roll)(table[key][index])) {
                currentLoot.add(itemName);
                return;
            }
        }
    };
}
exports.makeRevTable = makeRevTable;
/**
 * Adds random variation to a number. For example, if you pass 10%, it can at most lower the value by 10%,
 * or increase it by 10%, and everything in between.
 * @param value The value to add variation too.
 * @param percentage The max percentage to fluctuate the value by, in both negative/positive.
 */
function randomVariation(value, percentage) {
    const lowerLimit = value * (1 - percentage / 100);
    const upperLimit = value * (1 + percentage / 100);
    return (0, e_1.randFloat)(lowerLimit, upperLimit);
}
exports.randomVariation = randomVariation;
//# sourceMappingURL=util.js.map